==> pointpos_api-0.0.16.tar.gz: test/merchant_account_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for MerchantAccountApi
void main() {
  var instance = new MerchantAccountApi();

  group('tests for MerchantAccountApi', () {
    // Create Merchantaccount
    //
    // Create Merchantaccount
    //
    //Future<MerchantAccount> createMerchantaccount(String authorization, String xAPIKey, MerchantAccount body, { String xPin }) async 
    test('test createMerchantaccount', () async {
      // TODO
    });

    // Delete Merchantaccount By ID
    //
    // Delete Merchantaccount By ID
    //
    //Future deleteMerchantaccountByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteMerchantaccountByID', () async {
      // TODO
    });

    // Get Merchantaccount List
    //
    // Get Merchantaccount  List
    //
    //Future<List<MerchantAccount>> findMerchantaccount(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findMerchantaccount', () async {
      // TODO
    });

    // Get Merchantaccount By ID
    //
    // Get Merchantaccount By ID
    //
    //Future<MerchantAccount> getMerchantaccountByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getMerchantaccountByID', () async {
      // TODO
    });

    // Update Merchantaccount By ID
    //
    // Update [object Object] By ID
    //
    //Future<MerchantAccount> updateMerchantaccountByID(String authorization, String xAPIKey, String id, MerchantAccount body, { String xPin }) async 
    test('test updateMerchantaccountByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/merchant_account_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for MerchantAccountApi
void main() {
  var instance = new MerchantAccountApi();

  group('tests for MerchantAccountApi', () {
    // Create Merchantaccount
    //
    // Create Merchantaccount
    //
    //Future<MerchantAccount> createMerchantaccount(String authorization, String xAPIKey, MerchantAccount body, { String xPin }) async 
    test('test createMerchantaccount', () async {
      // TODO
    });

    // Delete Merchantaccount By ID
    //
    // Delete Merchantaccount By ID
    //
    //Future deleteMerchantaccountByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteMerchantaccountByID', () async {
      // TODO
    });

    // Get Merchantaccount List
    //
    // Get Merchantaccount  List
    //
    //Future<List<MerchantAccount>> findMerchantaccount(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findMerchantaccount', () async {
      // TODO
    });

    // Get Merchantaccount By ID
    //
    // Get Merchantaccount By ID
    //
    //Future<MerchantAccount> getMerchantaccountByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getMerchantaccountByID', () async {
      // TODO
    });

    // Update Merchantaccount By ID
    //
    // Update [object Object] By ID
    //
    //Future<MerchantAccount> updateMerchantaccountByID(String authorization, String xAPIKey, String id, MerchantAccount body, { String xPin }) async 
    test('test updateMerchantaccountByID', () async {
      // TODO
    });

  });
}
